/*
*Copyright(c)2014, Jeffrey Lee
*Allrightsreserved.
*
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met: 
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
*/

#include "input.h"

static const char *current_input_filename=NULL;
static int current_input_line=0;
static FILE *current_input_file=NULL;

bool input_open(const char *name)
{
	assert(!current_input_file);
	current_input_filename=name;
	current_input_line=0;
	current_input_file=fopen(name,"r");
	return (current_input_file!=NULL);
}

void input_close()
{
	if(current_input_file)
		fclose(current_input_file);
	current_input_file=NULL;
}

char *input_getline(char *buf,size_t size)
{
	assert(current_input_file);
	current_input_line++;
	return fgets(buf,size,current_input_file);
}

bool input_eof()
{
	assert(current_input_file);
	return feof(current_input_file);
}

void input_error(const char *format,...)
{
	va_list a;
	assert(current_input_file);
	va_start(a,format);
	fprintf(stderr,"%s:%d: error: ",current_input_filename,current_input_line);
	vfprintf(stderr,format,a);
	va_end(a);
}

void input_errorc(int column,const char *format,...)
{
	va_list a;
	assert(current_input_file);
	va_start(a,format);
	fprintf(stderr,"%s:%d:%d: error: ",current_input_filename,current_input_line,column+1);
	vfprintf(stderr,format,a);
	va_end(a);
}
